@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "bicycle" "1.1.2"
+(define-package "bicycle" "20251011.1822"
   "Cycle outline and code visibility."
   '((emacs  "28.1")
     (compat "30.1"))
   :url "https://github.com/tarsius/bicycle"
-  :commit "9da65dcb0e8ea6a9fe2b02d3be3cd4f2f4e29977"
-  :revdesc "v1.1.2-0-g9da65dcb0e8e"
+  :commit "562e2207b909dccffe921fd09dffa7add85f404d"
+  :revdesc "562e2207b909"
   :keywords '("outlines")
   :authors '(("Jonas Bernoulli" . "emacs.bicycle@jonas.bernoulli.dev"))
   :maintainers '(("Jonas Bernoulli" . "emacs.bicycle@jonas.bernoulli.dev")))
